/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class Coordinate3d extends BaseEntity {
	
	private Point3d point;

	public Coordinate3d(Point3d point) {
		this.point = point;
	}

	public Coordinate3d(double x, double y, double z) {
		this(new Point3d(x, y, z));
	}

	public Point3d getPoint() {
		return point;
	}

	public List<EdgePolygon> getPolygons() {
		List<HalfEdge> halfEdges = getParents(HalfEdge.class);
		
		Set<EdgePolygon> polygons = new HashSet<>();
		for (HalfEdge he : halfEdges) {
			List<EdgePolygon> localPolygons = he.getParents(EdgePolygon.class);
			polygons.addAll(localPolygons);
		}
		
		return new ArrayList<>(polygons);
	}

	@Override
	public String toString() {
		return "Coordinate3d [point=" + point + "]";
	}

}
