/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;


public class GmBoundedStraight extends GmStraight {
	
	private Point3d target;
	private double length;
	
	public static GmBoundedStraight of(Point3d point, Vector3d vector) {
		GmBoundedStraight straight = new GmBoundedStraight(point, vector.toUnitVector());
		straight.length = vector.getLength();
		straight.target = point.plus(vector);
		return straight;
	}
	
	public static GmBoundedStraight of(Point3d start, Point3d end) {
		Vector3d vec = end.minus(start);
		UnitVector3d dir = vec.toUnitVector();
		GmBoundedStraight straight = new GmBoundedStraight(start, dir);
		straight.target = end;
		straight.length = vec.getLength();
		return straight;
	}
	
	private GmBoundedStraight(Point3d start, UnitVector3d dir) {
		super(start, dir);
	}

	public Point3d getTarget() {
		return target;
	}
	
	public double getLength() {
		return length;
	}

}
