/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;


public class Interval {

	private static final Interval INVALID_INTERVAL = new Interval(1, 0);

	private double start;
	private double end;

	public Interval(double start, double end) {
		this.start = start;
		this.end = end;
	}

	public Interval overlap(Interval other) {
		if (isValid() && other.isValid() && isOverlapping(other)) {
			return new Interval(Math.max(start, other.start), Math.min(end, other.end));
		}
		return INVALID_INTERVAL;
	}

	public boolean isOverlapping(Interval other) {
		return !(end < other.start || other.end < start);
	}

	public boolean isValid() {
		return end >= start;
	}

	public double getLength() {
		return end - start;
	}

	public double getStart() {
		return start;
	}
	
	public double getEnd() {
		return end;
	}

	@Override
	public String toString() {
		return "Interval [start=" + start + ", end=" + end + "]";
	}

}
