/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class PolyLineSegment extends BaseEntity {

	private static final Logger logger = LogManager.getLogger(PolyLineSegment.class);

	private Coordinate3d mpStart;
	private Coordinate3d mpEnd;

	private PolyLineSegment mpNext;

	public PolyLineSegment(Coordinate3d cpStart, Coordinate3d cpEnd) {
		if (cpStart == cpEnd) {
			logger.warn("PolyLineSegment::PolyLineSegment() : start and end coordinate are the same object");
		}

		mpStart = cpStart;
		mpEnd = cpEnd;

		addChild(mpStart);
		addChild(mpEnd);
	}

	public void setNext(PolyLineSegment next) {
		mpNext = next;
	}

	public Coordinate3d getStart() {
		return mpStart;
	}

	public Coordinate3d getEnd() {
		return mpEnd;
	}

	public PolyLineSegment getNext() {
		return mpNext;
	}

	@Override
	public String toString() {
		return "PolyLineSegment [mpStart=" + mpStart + ", mpEnd=" + mpEnd + "]";
	}

}
