/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;


public class UnitVector3d extends Vector3d {

	public static UnitVector3d of(Vector3d vec) {
		UnitVector3d unitVec = new UnitVector3d(vec.getX(), vec.getY(), vec.getZ());
		unitVec.normalize();
		return unitVec;
	}
	
	public static UnitVector3d of(double x, double y, double z) {
		double length = Math.sqrt(x * x + y * y + z * z);
		return new UnitVector3d(x / length, y / length, z / length);
	}
	
	private UnitVector3d(double x, double y, double z) {
		super(x, y, z);
	}
	
	public double dot(UnitVector3d other) {
		double scalar = getX() * other.getX() + getY() * other.getY() + getZ() * other.getZ();
		if (scalar > 1.0) {
			return 1.0;
		}
		if (scalar < -1.0) {
			return -1.0;
		}
		return scalar;
	}



}
