/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;


public class Vector2d {

	private double x;
	private double y;

	public Vector2d(double x, double y) {
		this.x = x;
		this.y = y;
	}

	public Vector2d getPerpendicularVector() {
		return new Vector2d(y, -x);
	}

	public double dot(Vector2d other) {
		return (getX() * other.getX() + getY() * other.getY());
	}
	
	public Vector2d mult(double scalar) {
		return new Vector2d(x * scalar, y * scalar);
	}

	public double getX() {
		return x;
	}

	public double getY() {
		return y;
	}
	
	public UnitVector2d normalize() {
		return UnitVector2d.convertFrom(this);
	}

	public double getLength() {
		return Math.sqrt(getLength2());
	}

	public double getLength2() {
		return x * x + y * y;
	}

	@Override
	public String toString() {
		return "Vector2d [x=" + x + ", y=" + y + "]";
	}

}
