/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check;

import java.util.Collection;

import de.hft.stuttgart.citydoctor2.datastructure.BoundarySurface;
import de.hft.stuttgart.citydoctor2.datastructure.Edge;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;
import de.hft.stuttgart.citydoctor2.math.Vector3d;

/**
 * This is an interface to get information from errors. The errors will call one
 * or more methods listed here and the implementation can then handle the
 * information given. This is used in reports and the GUI.
 * 
 * @author Matthias Betz
 *
 */
public interface ErrorReport {

	public void add(Polygon p);

	public void add(LinearRing lr);

	public void add(Geometry geom);

	public void add(Vertex v);

	public void add(String name, Vertex v);

	public void add(Edge e);

	public void add(BoundarySurface bs);

	public void add(String name, Edge e);

	public void add(String name, int value);

	public void add(String name, double value);

	public void add(String name, String value);

	public void add(String name, Vector3d point);

	public void addPolygons(String name, Collection<Polygon> polygons);

	public void addEdges(String name, Collection<Edge> edges);

}
