/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check;

import de.hft.stuttgart.citydoctor2.check.error.AllPolygonsWrongOrientationError;
import de.hft.stuttgart.citydoctor2.check.error.ConsecutivePointSameError;
import de.hft.stuttgart.citydoctor2.check.error.DependenciesNotMetError;
import de.hft.stuttgart.citydoctor2.check.error.DistanceError;
import de.hft.stuttgart.citydoctor2.check.error.DuplicatePointError;
import de.hft.stuttgart.citydoctor2.check.error.EdgeIntersectionError;
import de.hft.stuttgart.citydoctor2.check.error.HoleOutsideError;
import de.hft.stuttgart.citydoctor2.check.error.InteriorDisconnectedError;
import de.hft.stuttgart.citydoctor2.check.error.ManifoldEdgeError;
import de.hft.stuttgart.citydoctor2.check.error.MultipleConnectedComponentsError;
import de.hft.stuttgart.citydoctor2.check.error.NestedRingError;
import de.hft.stuttgart.citydoctor2.check.error.NonManifoldVertexError;
import de.hft.stuttgart.citydoctor2.check.error.NormalDeviationError;
import de.hft.stuttgart.citydoctor2.check.error.NotCeilingError;
import de.hft.stuttgart.citydoctor2.check.error.NotFloorError;
import de.hft.stuttgart.citydoctor2.check.error.NotGroundError;
import de.hft.stuttgart.citydoctor2.check.error.NotWallError;
import de.hft.stuttgart.citydoctor2.check.error.NullAreaError;
import de.hft.stuttgart.citydoctor2.check.error.PointTouchesEdgeError;
import de.hft.stuttgart.citydoctor2.check.error.PolygonSelfIntError;
import de.hft.stuttgart.citydoctor2.check.error.PolygonWrongOrientationError;
import de.hft.stuttgart.citydoctor2.check.error.RingNotClosedError;
import de.hft.stuttgart.citydoctor2.check.error.RingSelfIntError;
import de.hft.stuttgart.citydoctor2.check.error.SameOrientationError;
import de.hft.stuttgart.citydoctor2.check.error.SchematronError;
import de.hft.stuttgart.citydoctor2.check.error.SolidNotClosedError;
import de.hft.stuttgart.citydoctor2.check.error.SolidSelfIntError;
import de.hft.stuttgart.citydoctor2.check.error.SurfaceUnfragmentedError;
import de.hft.stuttgart.citydoctor2.check.error.TinyEdgeError;
import de.hft.stuttgart.citydoctor2.check.error.TooFewPointsError;
import de.hft.stuttgart.citydoctor2.check.error.TooFewPolygonsError;
import de.hft.stuttgart.citydoctor2.check.error.UnknownCheckError;

/**
 * Visitor pattern interface to access errors. This is to determine the type of
 * an error without resorting to endless instanceof structures.
 * 
 * @author Matthias Betz
 *
 */
public interface ErrorVisitor {

	public void visit(HoleOutsideError err);

	public void visit(ManifoldEdgeError err);

	public void visit(MultipleConnectedComponentsError err);

	public void visit(NestedRingError err);

	public void visit(NonManifoldVertexError err);

	public void visit(PolygonWrongOrientationError err);

	public void visit(SameOrientationError err);

	public void visit(SolidNotClosedError err);

	public void visit(DependenciesNotMetError err);

	public void visit(UnknownCheckError err);

	public void visit(RingNotClosedError err);

	public void visit(ConsecutivePointSameError err);

	public void visit(RingSelfIntError err);

	public void visit(AllPolygonsWrongOrientationError err);

	public void visit(InteriorDisconnectedError err);

	public void visit(NullAreaError err);

	public void visit(TooFewPointsError err);

	public void visit(NormalDeviationError err);

	public void visit(DistanceError err);

	public void visit(PolygonSelfIntError err);

	public void visit(SolidSelfIntError err);

	public void visit(TooFewPolygonsError err);

	public void visit(DuplicatePointError err);

	public void visit(EdgeIntersectionError err);

	public void visit(PointTouchesEdgeError err);

	public void visit(NotCeilingError err);

	public void visit(NotFloorError err);

	public void visit(NotWallError err);

	public void visit(NotGroundError err);

	public void visit(CheckError err);
	
	public void visit(SchematronError err);
	
	public void visit(SurfaceUnfragmentedError err);
	
	public void visit(TinyEdgeError err);

}
