/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;

/**
 * When a point is repeated in a linear ring, but is not consecutive. This
 * results in a self intersection of the ring and this error object is created.
 * 
 * @author Matthias Betz
 *
 */
public class DuplicatePointError extends CheckError {

	private static final long serialVersionUID = 7208982075173209953L;
	
	private LinearRing r;
	private Vertex v1;
	private Vertex v2;

	public DuplicatePointError(LinearRing r, Vertex v1, Vertex v2) {
		super(ErrorId.GE_R_SELF_INTERSECTION, ErrorType.ERROR, r);
		this.r = r;
		this.v1 = v1;
		this.v2 = v2;
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	public LinearRing getRing() {
		return r;
	}

	public Vertex getVertex1() {
		return v1;
	}

	public Vertex getVertex2() {
		return v2;
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public void report(ErrorReport report) {
		report.add(r);
		report.add("duplicate point 1", v1);
		report.add("duplicate point 2", v2);
	}

	@Override
	public String toString() {
		return "DuplicatePointError [r=" + r + ", v1=" + v1 + ", v2=" + v2 + "]";
	}

}
