/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.Edge;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;

/**
 * If a point of a linear ring touches an edge of the same ring it is considered
 * self intersecting and this error object is created.
 * 
 * @author Matthias Betz
 *
 */
public class PointTouchesEdgeError extends CheckError {

	private static final long serialVersionUID = 3277456707271748954L;
	
	private LinearRing lr;
	private Edge e;
	private Vertex v;

	public PointTouchesEdgeError(LinearRing lr, Edge e, Vertex v) {
		super(ErrorId.GE_R_SELF_INTERSECTION, ErrorType.ERROR, lr);
		this.lr = lr;
		this.e = e;
		this.v = v;
	}

	public LinearRing getRing() {
		return lr;
	}

	public Edge getEdge() {
		return e;
	}

	public Vertex getVertex() {
		return v;
	}

	@Override
	public void report(ErrorReport report) {
		report.add("type", "point touches edge");
		report.add(lr);
		report.add(v);
		report.add(e);
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public String toString() {
		return "PointTouchesEdgeError [lr=" + lr + ", e=" + e + ", v=" + v + "]";
	}

}
