/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import java.util.Set;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.Edge;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;

/**
 * If two edges of the same linear ring are intersecting with each other, this
 * error is created.
 * 
 * @author Matthias Betz
 *
 */
public class RingSelfIntError extends CheckError {

	private static final long serialVersionUID = 8007952264635395514L;
	
	private LinearRing lr;
	private Set<Edge> edges;

	public RingSelfIntError(LinearRing lr, Set<Edge> intersectingEdges) {
		super(ErrorId.GE_R_SELF_INTERSECTION, ErrorType.ERROR, lr);
		this.lr = lr;
		edges = intersectingEdges;
	}

	public LinearRing getRing() {
		return lr;
	}

	public Set<Edge> getEdges() {
		return edges;
	}

	@Override
	public void report(ErrorReport report) {
		report.add(lr);
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public String toString() {
		return "RingSelfIntError [lr=" + lr + ", edges=" + edges + "]";
	}
}
