/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;

/**
 * If the interior rings have the same orientation as the exterior ring, this
 * error is created.
 * 
 * @author Matthias Betz
 *
 */
public class SameOrientationError extends CheckError {

	private static final long serialVersionUID = -6192337889977667459L;
	
	private Polygon p;
	private LinearRing innerRing;

	public SameOrientationError(Polygon p, LinearRing inner) {
		super(ErrorId.GE_P_ORIENTATION_RINGS_SAME, ErrorType.ERROR, p);
		this.p = p;
		this.innerRing = inner;
	}

	public Polygon getPolygon() {
		return p;
	}

	public LinearRing getInnerRing() {
		return innerRing;
	}

	@Override
	public void report(ErrorReport report) {
		report.add(p);
		report.add(innerRing);
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public String toString() {
		return "SameOrientationError [p=" + p + ", innerRing=" + innerRing + "]";
	}
}
