/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;

/**
 * When a geometry has less than 4 polygons, it cannot form a valid solid.
 * 
 * @author Matthias Betz
 *
 */
public class TooFewPolygonsError extends CheckError {

	private static final long serialVersionUID = 5800732409355221678L;
	
	private Geometry g;

	public TooFewPolygonsError(Geometry g) {
		super(ErrorId.GE_S_TOO_FEW_POLYGONS, ErrorType.ERROR, g);
		this.g = g;
	}

	public Geometry getGeometry() {
		return g;
	}

	@Override
	public void report(ErrorReport report) {
		report.add(g);
		report.add("number of polygons", g.getPolygons().size());
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public String toString() {
		return "TooFewPolygonsError [g=" + g + "]";
	}
}
