/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import de.hft.stuttgart.citydoctor2.check.Check;
import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.check.Checkable;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;

/**
 * This error is created when an unexpected exception is thrown by the code.
 * 
 * @author Matthias Betz
 *
 */
public class UnknownCheckError extends CheckError {

	private static final long serialVersionUID = -6554097632341055596L;
	
	private Checkable c;
	private Exception e;
	private CheckId checkId;

	public UnknownCheckError(Checkable c, Exception e, Check check) {
		super(ErrorId.UNKNOWN_ERROR, ErrorType.ERROR, null);
		this.c = c;
		this.e = e;
		checkId = check.getCheckId();
	}

	public CheckId getCheck() {
		return checkId;
	}

	public Checkable getCheckable() {
		return c;
	}

	public Exception getException() {
		return e;
	}

	@Override
	public void report(ErrorReport report) {
		report.add("check", checkId.toString());
		report.add("exception", e.getClass().getSimpleName());
		report.add("object", c.getGmlId().getGmlString());
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public String toString() {
		return "UnknownCheckError [c=" + c + ", e=" + e + "]";
	}
}
