/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.datastructure;

import java.util.ArrayList;
import java.util.List;

import org.citygml4j.factory.GMLGeometryFactory;
import org.citygml4j.model.citygml.building.AbstractBoundarySurface;
import org.citygml4j.model.citygml.building.BoundarySurfaceProperty;
import org.citygml4j.model.citygml.building.BuildingInstallationProperty;

import de.hft.stuttgart.citydoctor2.check.Check;
import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.parser.ParserConfiguration;

public class Building extends AbstractBuilding {

	private static final long serialVersionUID = 588480113268630052L;

	private List<BuildingPart> buildingParts = new ArrayList<>(2);

	public List<BuildingPart> getBuildingParts() {
		return buildingParts;
	}

	@Override
	public Building copy() {
		return (Building) super.copy();
	}
	
	@Override
	public void reCreateGeometries(GMLGeometryFactory factory, ParserConfiguration config) {
		super.reCreateGeometries(factory, config);
		for (BuildingPart bp : buildingParts) {
			bp.reCreateGeometries(factory, config);
		}
	}

	@Override
	public void accept(Check c) {
		super.accept(c);
		if (c.canExecute(this)) {
			c.check(this);
		}
		for (BuildingPart bp : buildingParts) {
			bp.accept(c);
		}
	}

	@Override
	public void clearAllContainedCheckResults() {
		super.clearAllContainedCheckResults();
		for (BuildingPart bp : buildingParts) {
			bp.clearAllContainedCheckResults();
		}
	}

	@Override
	public void collectContainedErrors(List<CheckError> errors) {
		super.collectContainedErrors(errors);
		for (BuildingPart bp : buildingParts) {
			bp.collectContainedErrors(errors);
		}
	}

	@Override
	public boolean containsAnyError() {
		boolean hasError = super.containsAnyError();
		if (hasError) {
			return true;
		}
		for (BuildingPart bp : buildingParts) {
			if (bp.containsAnyError()) {
				return true;
			}
		}
		return false;
	}

	@Override
	public boolean containsError(CheckId checkIdentifier) {
		boolean hasError = super.containsError(checkIdentifier);
		if (hasError) {
			return true;
		}
		for (BuildingPart bp : buildingParts) {
			if (bp.containsError(checkIdentifier)) {
				return true;
			}
		}
		return false;
	}

	public void addBuildingPart(BuildingPart buildingPart) {
		buildingParts.add(buildingPart);
	}

	@Override
	public String toString() {
		return "Building [id=" + getGmlId() + "]";
	}

	public void anonymize() {
		for (Geometry geom : getGeometries()) {
			geom.anonymize();
		}
		org.citygml4j.model.citygml.building.Building gmlB = new org.citygml4j.model.citygml.building.Building();
		gmlB.setId(GmlId.generateId().getGmlString());
		for (BuildingInstallation bi : getBuildingInstallations()) {
			bi.anonymize();
			gmlB.addOuterBuildingInstallation(new BuildingInstallationProperty(bi.getGmlObject()));
		}
		for (BoundarySurface bs : getBoundarySurfaces()) {
			bs.anonymize();
			gmlB.addBoundedBySurface(new BoundarySurfaceProperty((AbstractBoundarySurface) bs.getGmlObject()));
		}
		setCityGmlBuilding(gmlB);
	}
}
