/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.datastructure;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.UncheckedIOException;

import de.hft.stuttgart.citydoctor2.check.Check;
import de.hft.stuttgart.citydoctor2.check.Checkable;

/**
 * A general GML element that has a gml id
 * 
 * @author Matthias Betz
 *
 */
public abstract class GmlElement extends Checkable {

	private static final long serialVersionUID = -3242505393303017359L;

	private GmlId gmlId;

	public GmlElement copy() {
		ByteArrayOutputStream arrayOutputStream = new ByteArrayOutputStream();
		try {
			ObjectOutputStream oos = new ObjectOutputStream(arrayOutputStream);
			oos.writeObject(this);
			ObjectInputStream ooi = new ObjectInputStream(new ByteArrayInputStream(arrayOutputStream.toByteArray()));
			return (GmlElement) ooi.readObject();
		} catch (IOException e) {
			throw new UncheckedIOException(e);
		} catch (ClassNotFoundException e) {
			throw new IllegalStateException(e);
		}
	}

	@Override
	public void accept(Check c) {
		if (c.canExecute(this)) {
			c.check(this);
		}
		setValidated(true);
	}

	public void setGmlId(GmlId id) {
		gmlId = id;
	}

	@Override
	public GmlId getGmlId() {
		if (gmlId == null) {
			gmlId = GmlId.generateId();
		}
		return gmlId;
	}
}
