/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.datastructure;

import java.util.List;

import de.hft.stuttgart.citydoctor2.math.Vector3d;
import de.hft.stuttgart.citydoctor2.tesselation.TesselatedPolygon;

/**
 * Interface for concrete and linked polygons.
 * 
 * @author Matthias Betz
 *
 */
public abstract class Polygon extends GmlElement {

	private static final long serialVersionUID = -613942946364706513L;

	public abstract Vector3d calculateNormal();

	public abstract TesselatedPolygon tesselate();

	public abstract LinearRing getExteriorRing();

	public abstract List<LinearRing> getInnerRings();

	public abstract boolean isPointInsideExteriorRing(Vector3d v);

	public abstract Geometry getParent();

	public abstract void setParent(Geometry geometry);

	public abstract void setExteriorRing(LinearRing extRing);

	public abstract boolean isPolygonConnectedViaPoint(Polygon other);

	public abstract void addInteriorRing(LinearRing inter);

	public abstract BoundarySurface getPartOfSurface();

	public abstract void setPartOfSurface(BoundarySurface bs);

	public abstract void removeInnerRing(LinearRing ring);

	public abstract void setPartOfInstallation(BuildingInstallation bi);

	public abstract BuildingInstallation getPartOfInstallation();

	public abstract boolean hasPointAsCorner(Vertex v);

	public abstract void removeRings();

	public abstract boolean isLinkedTo();

	public abstract boolean isLink();

	public abstract LinkedPolygon getLinkedFromPolygon();

	abstract void anonymize();

	public abstract ConcretePolygon getOriginal();

}