/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.math;

import java.util.List;

import Jama.Matrix;
import Jama.SingularValueDecomposition;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;

/**
 * Utility class to calculate three dimensional regression lines of a list of
 * vertices
 * 
 * @author Matthias Betz
 *
 */
public class OrthogonalRegressionLine {

	private OrthogonalRegressionLine() {

	}

	public static Line3d getRegressionLine(List<Vertex> vertices) {
		// get the center of all points, the line has to go through this point
		Vector3d centroid = CovarianceMatrix.getCentroid(vertices);
		// create covariance matrix (3 x 3) out of all used points
		double[][] covMatrixValues = CovarianceMatrix.calculateCovarianceMatrix(vertices, centroid);
		Matrix covMatrix = new Matrix(covMatrixValues);
		SingularValueDecomposition svd = new SingularValueDecomposition(covMatrix);

		Matrix direction = svd.getU().getMatrix(0, 2, 0, 0);
		Vector3d dir = new Vector3d(direction.get(0, 0), direction.get(1, 0), direction.get(2, 0));
		return new Line3d(centroid, dir);
	}

}
