/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.math.graph;

import java.util.Deque;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;
import java.util.concurrent.atomic.AtomicInteger;

import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;

/**
 * A graph used to detect cycles.
 * 
 * @author Matthias Betz
 *
 */
public class CycleGraph {

	private final CycleNode root;

	public CycleGraph(CycleNode root) {
		this.root = root;
	}

	public List<List<LinearRing>> getConnectedComponents() {
		AtomicInteger index = new AtomicInteger();
		Deque<CycleNode> s = new LinkedList<>();
		List<List<LinearRing>> components = new LinkedList<>();
		Set<CycleNode> nodes = new HashSet<>();
		root.collectNodes(nodes);
		for (CycleNode node : nodes) {
			if (node.getIndex() == -1) {
				node.strongConnect(s, index, components);
			}
		}
		return components;
	}

	public boolean hasMoreThan2CycleDepth() {
		return root.hasMoreThan2CycleDepth(null);
	}

}
