/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.parser;

import java.util.EventListener;

/**
 * Implementations of this listener will be informed about the (file) loading progress of ObservedInputStream
 * instances. You have to register your implementation of this interface at the ObservedInputStream instance.
 * 
 * @author Marcel Bruse
 */
public interface InputStreamListener extends EventListener {
	
	/**
	 * This method will be called by the observed input stream when a new chunk of bytes has been read. 
	 * 
	 * @param progress Should be a value between 0 and 1. 0 means no progress and 1 means loading finished. 
	 */
	public void updateProgress(float progress);
	
}
