/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.parser;

/**
 * ProgressListeners can be registered at CityGMLParsers in order to get updates about file loading and
 * file parsing processes. Every update tells the ProgressListener the processing progress in percent, normalized
 * to values between 0 and 1.
 * 
 * @author Marcel Bruse
 */
public interface ProgressListener {

	/**
	 * This is a callback that will be called if a file loading process progresses. The file loading process will 
	 * be performed by a CityGMLParser.  
	 * 
	 * @param progress The progress of the current file loading process. The argument will be a value between 0 and 1.
	 * 0 means that no byte has been read by the CityGMLParser so far and 1 means, that the reading and parsing process
	 * is finished. 
	 */
	public void updateProgress(float progress);
	
}