/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.parser;

import java.lang.reflect.Field;

import org.osgeo.proj4j.proj.Projection;
import org.osgeo.proj4j.units.Unit;

/**
 * To extract the unit of the coordinate system. Workaround as the library
 * proj4j has no getter to access the unit value
 * 
 * @author Matthias Betz
 *
 */
public class ProjectionUnitExtractor {

	private Unit unit;

	public ProjectionUnitExtractor(Projection proj) {
		try {
			Field f = Projection.class.getDeclaredField("unit");
			f.setAccessible(true);
			unit = (Unit) f.get(proj);
		} catch (NoSuchFieldException | SecurityException | IllegalArgumentException | IllegalAccessException e) {
			throw new IllegalArgumentException(e);
		}
	}

	public Unit getUnit() {
		return unit;
	}

}
