/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.utils;

import java.util.List;

import de.hft.stuttgart.citydoctor2.datastructure.ConcretePolygon;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.math.Segment3d;

/**
 * Result of a polygon polygon intersection.
 * 
 * @author Matthias Betz
 *
 */
public class PolygonIntersection {

	public enum IntersectionType {
		NONE, LINE, POLYGON
	}

	private IntersectionType type;
	private List<Segment3d> lines;
	private ConcretePolygon polygon;

	private Polygon p1;
	private Polygon p2;

	public static PolygonIntersection none() {
		return new PolygonIntersection(IntersectionType.NONE);
	}

	public static PolygonIntersection lines(List<Segment3d> lines, Polygon p1, Polygon p2) {
		PolygonIntersection poly = new PolygonIntersection(IntersectionType.LINE);
		poly.lines = lines;
		poly.p1 = p1;
		poly.p2 = p2;
		return poly;
	}

	public static PolygonIntersection polygon(ConcretePolygon polygon, Polygon p1, Polygon p2) {
		PolygonIntersection poly = new PolygonIntersection(IntersectionType.POLYGON);
		poly.polygon = polygon;
		poly.p1 = p1;
		poly.p2 = p2;
		return poly;
	}

	public Polygon getP1() {
		return p1;
	}

	public Polygon getP2() {
		return p2;
	}

	private PolygonIntersection(IntersectionType type) {
		this.type = type;
	}

	public IntersectionType getType() {
		return type;
	}

	public List<Segment3d> getLines() {
		return lines;
	}

	public ConcretePolygon getIntersectionPolygon() {
		return polygon;
	}

	@Override
	public String toString() {
		return "PolygonIntersection [type=" + type + ", lines=" + lines + ", polygon=" + polygon + ", p1=" + p1
				+ ", p2=" + p2 + "]";
	}

}
