/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 * The configuration of a single check. A check can have parameters and be
 * enabled or disabled.
 * 
 * @author Matthias Betz
 *
 */
public class CheckConfiguration implements Serializable {

	private static final long serialVersionUID = -1258195428669813888L;

	private boolean enabled;
	private Map<String, String> parameters;

	/**
	 * @return Whether this check is enabled
	 */
	public boolean isEnabled() {
		return enabled;
	}

	/**
	 * @param enabled Enable or disable this check
	 */
	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
	}

	/**
	 * @return The parameters given for this check.
	 */
	public Map<String, String> getParameters() {
		if (parameters == null) {
			parameters = new HashMap<>();
		}
		return parameters;
	}

	/**
	 * @param parameters Sets the parameters of this check.
	 */
	public void setParameters(Map<String, String> parameters) {
		this.parameters = parameters;
	}

	@Override
	public String toString() {
		return "CheckConfiguration [enabled=" + enabled + ", parameters=" + parameters + "]";
	}

}
