/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.checks.util;

import de.hft.stuttgart.citydoctor2.math.Ring2d;
import de.hft.stuttgart.citydoctor2.math.Vector2d;

/**
 * Utility class to calculate the orientation
 * 
 * @author Matthias Betz
 *
 */
public final class RingOrientationUtil {

	private RingOrientationUtil() {

	}

	/**
	 * Calculates whether a point is left, right or on the line
	 * 
	 * @param v1 first point of the line
	 * @param v2 second point of the line
	 * @param v3 checking point
	 * @return > 0: left of the line<br>
	 *         = 0: on the line<br>
	 *         < 0: right of the line
	 */
	@SuppressWarnings("unused")
	private static double calcPointLineOrientation(Vector2d v1, Vector2d v2, Vector2d v3) {
		return ((v2.getX() - v1.getX()) * (v3.getY() - v1.getY()) - (v3.getX() - v1.getX()) * (v2.getY() - v1.getY()));
	}

	public static Orientation calculateOrientation(Ring2d ring) {
		double sum = 0;
		for (int i = 0; i < ring.getVertices().size() - 1; i++) {
			Vector2d v1 = ring.getVertices().get(i);
			Vector2d v2 = ring.getVertices().get(i + 1);
			sum = sum + (v2.getX() - v1.getX()) * (v2.getY() + v1.getY());
		}
		if (sum < 0) {
			return Orientation.COUNTER_CLOCKWISE;
		}
		return Orientation.CLOCKWISE;
	}

}
