/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.reporting;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * Class for storing the amount of errors per error type
 * 
 * @author Matthias Betz
 *
 */
public class ErrorStatisticsCollector {

	private Map<String, AtomicInteger> errorCounts = new HashMap<>();

	public void addError(String errorName) {
		AtomicInteger numErrors = errorCounts.get(errorName);
		if (numErrors == null) {
			errorCounts.put(errorName, new AtomicInteger(1));
		} else {
			numErrors.incrementAndGet();
		}
	}

	public Map<String, AtomicInteger> getErrorCounts() {
		return errorCounts;
	}

	public void add(ErrorStatisticsCollector otherStats) {
		for (Entry<String, AtomicInteger> errorCount : otherStats.getErrorCounts().entrySet()) {
			AtomicInteger oldValue = errorCounts.get(errorCount.getKey());
			if (oldValue == null) {
				errorCounts.put(errorCount.getKey(), new AtomicInteger(errorCount.getValue().get()));
			} else {
				oldValue.addAndGet(errorCount.getValue().get());
			}
		}
	}

}
