/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.reporting;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.checkresult.utility.CheckReportWriteException;
import de.hft.stuttgart.citydoctor2.datastructure.CityObject;

/**
 * Interface to write reports from streams of features
 * 
 * @author Matthias Betz
 *
 */
public interface StreamReporter {

	public void report(CityObject co);

	public void finishReport() throws CheckReportWriteException;

	public void reportGlobalError(CheckError err);

	/**
	 * Add an error to a feature. The GML ID can be one of Building, BuildingPart,
	 * Vegetation, Transportation, Land, Water or Bridge. No Polygon or Ring IDs are
	 * valid. This is used for Schematron errors, as the Schematron validation
	 * happens after all internal checks are done.
	 * 
	 * @param gmlId the GML ID where the error belongs to
	 * @param err   the error object.
	 */
	public void addError(String gmlId, CheckError err);

}
