/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.reporting;

import java.io.OutputStream;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ValidationConfiguration;
import de.hft.stuttgart.citydoctor2.checkresult.utility.CheckReportWriteException;
import de.hft.stuttgart.citydoctor2.checks.Checks;
import de.hft.stuttgart.citydoctor2.datastructure.BridgeObject;
import de.hft.stuttgart.citydoctor2.datastructure.Building;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.datastructure.LandObject;
import de.hft.stuttgart.citydoctor2.datastructure.TransportationObject;
import de.hft.stuttgart.citydoctor2.datastructure.Vegetation;
import de.hft.stuttgart.citydoctor2.datastructure.WaterObject;

/**
 * 
 * @author Matthias Betz
 *
 */
public class XmlValidationReporter implements Reporter {

	@Override
	public void writeReport(Checks checks, OutputStream filePath, CityDoctorModel model, ValidationConfiguration config) throws CheckReportWriteException {
		StreamReporter streamReporter = new XmlStreamReporter(filePath, model.getFileName(), config);
		for (BridgeObject bo : model.getBridges()) {
			streamReporter.report(bo);
		}
		for (Building b : model.getBuildings()) {
			streamReporter.report(b);
		}
		for (TransportationObject to : model.getTransportation()) {
			streamReporter.report(to);
		}
		for (LandObject lo : model.getLand()) {
			streamReporter.report(lo);
		}
		for (Vegetation v : model.getVegetation()) {
			streamReporter.report(v);
		}
		for (WaterObject wo : model.getWater()) {
			streamReporter.report(wo);
		}
		for (CheckError err : model.getGlobalErrors()) {
			streamReporter.reportGlobalError(err);
		}
		streamReporter.finishReport();
	}

}
