/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.reporting.pdf;

import java.io.OutputStream;
import java.util.Objects;

import de.hft.stuttgart.citydoctor2.check.ValidationConfiguration;
import de.hft.stuttgart.citydoctor2.checkresult.utility.CheckReportWriteException;
import de.hft.stuttgart.citydoctor2.checks.Checks;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.reporting.Reporter;

/**
 * Reporter to write a PDF report from a complete model
 * 
 * @author Matthias Betz
 *
 */
public class PdfReporter implements Reporter {

	private String logoPath;

	public PdfReporter(String logoPath) {
		Objects.requireNonNull(logoPath);
		this.logoPath = logoPath;
	}

	@Override
	public void writeReport(Checks checks, OutputStream outFile, CityDoctorModel model, ValidationConfiguration config)
			throws CheckReportWriteException {
		PdfStreamReporter reporter = new PdfStreamReporter(outFile, model.getFileName(), config, logoPath);
		model.createFeatureStream().forEach(reporter::report);
		reporter.finishReport();
	}
}
