/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.IOException;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.CityDoctorValidation;
import de.hft.stuttgart.citydoctor2.datastructure.Building;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParseException;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParser;
import de.hft.stuttgart.citydoctor2.parser.InvalidGmlFileException;

/**
 * 
 * @author Matthias Betz
 *
 */
public class CheckerTest {

	@Test
	public void testSchematron() throws CityGmlParseException, InvalidGmlFileException {
		ValidationConfiguration config = ValidationConfiguration.loadStandardValidationConfig();
		config.getChecks().get(CheckId.C_SEM_BS_ROOF_NOT_FRAGMENTED).setEnabled(false);
		config.setSchematronFilePath("src/test/resources/schematronTest.xml");
		CityDoctorModel model = CityGmlParser.parseCityGmlFile(
				"src/test/resources/SimpleSolid_SrefBS_SchematronTest.gml", config.getParserConfiguration());
		Checker checker = new Checker(config, model);
		checker.runChecks();
		for (Building b : model.getBuildings()) {
			if (!b.getGmlId().getGmlString().startsWith("UUID")) {
				// if it starts with UUID the gml id was generated by citygml4j, but the file
				// does not actually contain that gml id
				// the schematron errors cannot be assigned to buildings without gml id, so they
				// are excluded here
				assertTrue(b.containsAnyError());
			}
		}
		assertFalse(model.getGlobalErrors().isEmpty());
	}

	@Test
	public void testChecker() throws CityGmlParseException, IOException, InterruptedException, InvalidGmlFileException {
		String[] args = new String[6];
		args[0] = "-in";
		args[1] = "src/test/resources/QA-CS-CONCOMP.gml";
		args[2] = "-xmlReport";
		args[3] = "test.xml";
		args[4] = "-pdfReport";
		args[5] = "test.pdf";
		CityDoctorValidation.main(args);
		File f = new File("test.xml");
		assertTrue(f.exists());
		f.delete();
		File f2 = new File("test.pdf");
		assertTrue(f2.exists());
		f2.delete();
	}

	@Test
	public void testStreaming()
			throws CityGmlParseException, IOException, InterruptedException, InvalidGmlFileException {
		String[] args = new String[8];
		args[0] = "-in";
		args[1] = "src/test/resources/testarea.gml";
		args[2] = "-config";
		args[3] = "src/test/resources/testConfigWithStreaming.yml";
		args[4] = "-pdfReport";
		args[5] = "test.pdf";
		args[6] = "-xmlReport";
		args[7] = "test.xml";
		CityDoctorValidation.main(args);
		File f = new File("test.pdf");
		assertTrue(f.exists());
		f.delete();
		File f2 = new File("test.xml");
		assertTrue(f2.exists());
		f2.delete();
	}
}
