/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.checks.geometry;

import org.junit.Assert;
import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.ConcretePolygon;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.GeometryType;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing.LinearRingType;
import de.hft.stuttgart.citydoctor2.datastructure.Lod;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;

/**
 * 
 * @author Matthias Betz
 *
 */
public class NullAreaCheckTest {
	
	private LinearRing setupValidGeometry() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD1);
		
		Polygon p = new ConcretePolygon();
		geom.addPolygon(p);
		
		LinearRing r = new LinearRing(LinearRingType.EXTERIOR);
		p.setExteriorRing(r);
		
		Vertex v1 = new Vertex(0, 0, 0);
		r.addVertex(v1);
		
		Vertex v2 = new Vertex(1, 1, 0);
		r.addVertex(v2);
		
		Vertex v3 = new Vertex(2, 2, 0);
		r.addVertex(v3);
		
		Vertex v4 = new Vertex(5, 5.5, 0);
		r.addVertex(v4);
		r.addVertex(v1);
		return r;
	}
	
	private LinearRing setupErrorGeometry() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD1);
		
		Polygon p = new ConcretePolygon();
		geom.addPolygon(p);
		
		LinearRing r = new LinearRing(LinearRingType.EXTERIOR);
		p.setExteriorRing(r);
		
		Vertex v1 = new Vertex(0, 0, 0);
		r.addVertex(v1);
		
		Vertex v2 = new Vertex(1, 1, 0);
		r.addVertex(v2);
		
		Vertex v3 = new Vertex(2, 2, 0);
		r.addVertex(v3);
		
		Vertex v4 = new Vertex(5, 5.00001, 0);
		r.addVertex(v4);
		r.addVertex(v1);
		return r;
	}
	
	@Test
	public void testCheckRingError() {
		LinearRing r = setupErrorGeometry();
		NullAreaCheck nac = new NullAreaCheck();
		nac.check(r);
		Assert.assertTrue(r.hasAnyError());
	}



	@Test
	public void testCheckRing() {
		LinearRing r = setupValidGeometry();
		NullAreaCheck nac = new NullAreaCheck();
		nac.check(r);
		Assert.assertFalse(r.hasAnyError());
	}

}
