/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.checks.geometry;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertSame;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.CheckResult;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ResultStatus;
import de.hft.stuttgart.citydoctor2.checks.util.GeometryTestUtils;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.GeometryType;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing.LinearRingType;
import de.hft.stuttgart.citydoctor2.datastructure.Lod;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;

/**
 * 
 * @author Matthias Betz
 *
 */
public class PolygonSameOrientationCheckTest {

	@Test
	public void testSameOrientation() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD1);

		Vertex v0 = GeometryTestUtils.createVertex(0, 0, 0, geom);
		Vertex v1 = GeometryTestUtils.createVertex(6, 0, 0, geom);
		Vertex v2 = GeometryTestUtils.createVertex(6, 6, 0, geom);
		Vertex v3 = GeometryTestUtils.createVertex(0, 6, 0, geom);
		Vertex v4 = GeometryTestUtils.createVertex(2, 2, 0, geom);
		Vertex v5 = GeometryTestUtils.createVertex(4, 2, 0, geom);
		Vertex v6 = GeometryTestUtils.createVertex(4, 4, 0, geom);
		Vertex v7 = GeometryTestUtils.createVertex(2, 4, 0, geom);
		
		Polygon poly = GeometryTestUtils.addPolygon(geom, v0, v1, v2, v3);
		
		LinearRing interior = new LinearRing(LinearRingType.INTERIOR);
		poly.addInteriorRing(interior);
		interior.addVertex(v4);
		interior.addVertex(v5);
		interior.addVertex(v6);
		interior.addVertex(v7);
		interior.addVertex(v4);
		
		PolygonSameOrientationCheck check = new PolygonSameOrientationCheck();
		check.check(poly);
		
		CheckResult cr = poly.getCheckResult(check);
		
		assertSame(ResultStatus.ERROR, cr.getResultStatus());
		assertEquals(ErrorId.GE_P_ORIENTATION_RINGS_SAME, cr.getError().getErrorId());
	}
	
	@Test
	public void testGoodPoly() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD1);

		Vertex v0 = GeometryTestUtils.createVertex(0, 0, 0, geom);
		Vertex v1 = GeometryTestUtils.createVertex(6, 0, 0, geom);
		Vertex v2 = GeometryTestUtils.createVertex(6, 6, 0, geom);
		Vertex v3 = GeometryTestUtils.createVertex(0, 6, 0, geom);
		Vertex v4 = GeometryTestUtils.createVertex(2, 2, 0, geom);
		Vertex v5 = GeometryTestUtils.createVertex(4, 2, 0, geom);
		Vertex v6 = GeometryTestUtils.createVertex(4, 4, 0, geom);
		Vertex v7 = GeometryTestUtils.createVertex(2, 4, 0, geom);
		
		Polygon poly = GeometryTestUtils.addPolygon(geom, v0, v1, v2, v3);
		
		LinearRing interior = new LinearRing(LinearRingType.INTERIOR);
		poly.addInteriorRing(interior);
		interior.addVertex(v4);
		interior.addVertex(v7);
		interior.addVertex(v6);
		interior.addVertex(v5);
		interior.addVertex(v4);
		
		
		PolygonSameOrientationCheck check = new PolygonSameOrientationCheck();
		check.check(poly);
		
		CheckResult cr = poly.getCheckResult(check);
		
		assertSame(ResultStatus.OK, cr.getResultStatus());
	}

}
