/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.systemtest;

import static org.junit.Assert.assertEquals;

import java.io.IOException;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.check.CheckResult;
import de.hft.stuttgart.citydoctor2.check.Checker;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ResultStatus;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParseException;
import de.hft.stuttgart.citydoctor2.parser.ParserConfiguration;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParser;
import de.hft.stuttgart.citydoctor2.parser.InvalidGmlFileException;

/**
 * 
 * @author Matthias Betz
 *
 */
public class NumPointsCheckTest {

	@Test
	public void testNumPoints1() throws CityGmlParseException, IOException, InvalidGmlFileException {
		ParserConfiguration config = new ParserConfiguration(8, false);
		CityDoctorModel m = CityGmlParser.parseCityGmlFile("src/test/resources/QA-Ex-C-LR-1.gml", config);
		Checker c = new Checker(m);
		c.runChecks();

		LinearRing r1 = TestUtil.getPolygonById("p_r_1", m).getExteriorRing();
		CheckResult cr1 = r1.getCheckResult(CheckId.C_GE_R_TOO_FEW_POINTS);
		assertEquals(ResultStatus.ERROR, cr1.getResultStatus());
		assertEquals(ErrorId.GE_R_TOO_FEW_POINTS, cr1.getError().getErrorId());

		LinearRing r2 = TestUtil.getPolygonById("p_w_4", m).getExteriorRing();
		assertEquals(ResultStatus.OK, r2.getCheckResult(CheckId.C_GE_R_TOO_FEW_POINTS).getResultStatus());
	}

	@Test
	public void testNumPoints2() throws CityGmlParseException, IOException, InvalidGmlFileException {
		ParserConfiguration config = new ParserConfiguration(8, false);
		CityDoctorModel m = CityGmlParser.parseCityGmlFile("src/test/resources/QA-Ex-C-LR-1GK.gml", config);
		Checker c = new Checker(m);
		c.runChecks();

		LinearRing r1 = TestUtil.getPolygonById("p_r_1", m).getExteriorRing();
		CheckResult cr1 = r1.getCheckResult(CheckId.C_GE_R_TOO_FEW_POINTS);
		assertEquals(ResultStatus.ERROR, cr1.getResultStatus());
		assertEquals(ErrorId.GE_R_TOO_FEW_POINTS, cr1.getError().getErrorId());

		LinearRing r2 = TestUtil.getPolygonById("p_w_4", m).getExteriorRing();
		assertEquals(ResultStatus.OK, r2.getCheckResult(CheckId.C_GE_R_TOO_FEW_POINTS).getResultStatus());
	}

	@Test
	public void testNumPoints3() throws CityGmlParseException, IOException, InvalidGmlFileException {
		CityDoctorModel c = TestUtil.loadAndCheckCityModel("src/test/resources/SimpleSolid_SrefBS.gml");

		for (Polygon p : c.getBuildings().get(0).getGeometries().get(0).getPolygons()) {
			LinearRing r = p.getExteriorRing();
			assertEquals(ResultStatus.OK, r.getCheckResult(CheckId.C_GE_R_TOO_FEW_POINTS).getResultStatus());
		}
	}

	@Test
	public void testNumPoints4() throws CityGmlParseException, IOException, InvalidGmlFileException {
		CityDoctorModel c = TestUtil.loadAndCheckCityModel("src/test/resources/SimpleSolid_SrefBS-GE-gml-LR-0001-T0001.gml");
		Polygon p = TestUtil.getPolygonById("_Simple_BD.1_PG.6", c);
		LinearRing r = p.getExteriorRing();
		assertEquals(ResultStatus.ERROR, r.getCheckResult(CheckId.C_GE_R_TOO_FEW_POINTS).getResultStatus());
	}

	@Test
	public void testNumPoints5() throws CityGmlParseException, IOException, InvalidGmlFileException {
		CityDoctorModel c = TestUtil.loadAndCheckCityModel("src/test/resources/SimpleSolid_SrefBS-GE-gml-LR-0001-T0002.gml");
		Polygon p = TestUtil.getPolygonById("_Simple_BD.1_PG.6", c);
		LinearRing r = p.getExteriorRing();
		assertEquals(ResultStatus.DEPENDENCIES_NOT_MET,
				r.getCheckResult(CheckId.C_GE_R_TOO_FEW_POINTS).getResultStatus());
	}

}
