/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.systemtest;

import static org.junit.Assert.assertEquals;

import java.io.IOException;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.check.CheckResult;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ResultStatus;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParseException;
import de.hft.stuttgart.citydoctor2.parser.InvalidGmlFileException;

/**
 * 
 * @author Matthias Betz
 *
 */
public class ShellNotClosedSystemTest {
	
	@Test
	public void testShellNotClosed1() throws CityGmlParseException, IOException, InvalidGmlFileException {
		CityDoctorModel c = TestUtil.loadAndCheckCityModel("src/test/resources/SimpleSolid_SrefBS.gml");
		Geometry g = c.getBuildings().get(0).getGeometries().get(0);
		CheckResult cr = g.getCheckResult(CheckId.C_GE_S_NOT_CLOSED);
		assertEquals(ResultStatus.OK, cr.getResultStatus());
	}
	
	@Test
	public void testShellNotClosed2() throws CityGmlParseException, IOException, InvalidGmlFileException {
		CityDoctorModel c = TestUtil.loadAndCheckCityModel("src/test/resources/SimpleSolid_SrefBS-GE-gml-SO-0002-T0001.gml");
		Geometry g = c.getBuildings().get(0).getGeometries().get(0);
		CheckResult cr = g.getCheckResult(CheckId.C_GE_S_NOT_CLOSED);
		assertEquals(ResultStatus.ERROR, cr.getResultStatus());
		assertEquals(ErrorId.GE_S_NOT_CLOSED, cr.getError().getErrorId());
	}

}
